@@ -9,7 +9,7 @@
  * GNU General Public License
  *
  *  This file is part of XCFA.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -29,7 +29,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  */
 
 
@@ -71,13 +71,13 @@ typedef struct {
 */
 GdkColor YellowColor = { 0, 63479,63479,48830 };
 
-// 
-// 
+//
+//
 gchar *libutils_dup_chomp( gchar *p_str )
 {
 	gchar	*StrNew = g_strdup( p_str );
 	gchar	*Ptr = StrNew;
-	
+
 	while( *Ptr ) {
 		if( '\n' == *Ptr ) *Ptr = '\0';
 		if( '\r' == *Ptr ) *Ptr = '\0';
@@ -85,8 +85,8 @@ gchar *libutils_dup_chomp( gchar *p_str )
 	}
 	return( StrNew );
 }
-// 
-// 
+//
+//
 gchar *libutils_chomp( gchar *p_str )
 {
 	gchar	*Ptr = p_str;
@@ -97,21 +97,21 @@ gchar *libutils_chomp( gchar *p_str )
 	}
 	return( p_str );
 }
-// 
-// 
+//
+//
 gchar *libutils_get_prefix (gchar *PathNameFile)
 {
 	gchar	*Prefix = g_strdup (PathNameFile);
 	gchar	*Ptr = NULL;
-	
+
 	if (NULL != (Ptr = strrchr (Prefix, '/'))) {
 		*Ptr = '\0';
 	}
-	
+
 	return (Prefix);
 }
-// 
-// 
+//
+//
 gboolean libutils_access_mode (gchar *PathNameFile)
 {
 	gboolean	FileAccessModeFileExist = access (PathNameFile, F_OK) == -1 ? FALSE : TRUE;
@@ -119,24 +119,42 @@ gboolean libutils_access_mode (gchar *PathNameFile)
 }
 // CREATION D UN DOSSIER TEMPORAIRE
 //
-gchar *libutils_create_temporary_rep (gchar *SrcTmp, gchar *NewRepTmp)
+gchar *libutils_create_temporary_rep( gchar *SrcTmp, gchar *NewRepTmp )
 {
-	//gchar	*LineCommand = NULL;
 	gchar	*Path = NULL;
+	gint	NumPath = 0;
 	
+	/*
 	if (NewRepTmp != NULL) {
 		Path = g_strdup_printf ("%s/%s", SrcTmp, NewRepTmp);
 		if (FALSE == libutils_test_dir_exist (Path)) {
 			if( TRUE == OptionsCommandLine.BoolVerboseMode )
 				g_print ("CREATE TEMPORARY REP:\n\t%s\n", Path);
 			g_mkdir_with_parents (Path, 0700);
-			// LineCommand = g_strdup_printf ("mkdir -p %s", Path);
-			// Dummy = system (LineCommand);
-			// g_free (LineCommand);
-			// LineCommand = NULL;
 		}
 	}
 	return ((gchar *)Path);
+	*/
+	// FIXED 
+	// Mon, 20 Jan 2014 16:33:36 +0100
+	// Plusieurs instances de XCFA peuvent être activées sans collision pour les conversions et extractions
+	//
+	while( TRUE ) {
+		Path = g_strdup_printf( "%s/%s_%d", SrcTmp, NewRepTmp, NumPath );
+		if( TRUE == g_file_test( Path, G_FILE_TEST_IS_DIR ) ) {
+			g_free( Path );
+			Path = NULL;
+		}
+		else {
+			if( TRUE == OptionsCommandLine.BoolVerboseMode )
+				g_print( "CREATE TEMPORARY REP:\n\t%s\n", Path );
+			g_mkdir_with_parents( Path, 0700 );
+			break;
+		}
+		NumPath ++;
+	}
+	
+	return( (gchar *)Path );
 }
 // SUPPRESSION D UN DOSSIER TEMPORAIRE
 //
@@ -172,12 +190,12 @@ gboolean libutils_test_file_exist (gchar *File)
 	return (g_file_test (File, G_FILE_TEST_IS_REGULAR));
 }
 // RENVOIE LE PAHTNAME AVEC LA NOUVELLE EXTENTION
-// 
+//
 gchar *libutils_get_pathname_with_new_ext (gchar *PathName, gchar *NewExt)
 {
 	gchar	*NewPathName = g_strdup_printf ("%s0123456789", PathName);
 	gchar	*Ptr = strrchr (NewPathName, '.');
-	
+
 	if (NULL == Ptr) {
 		for (Ptr = NewPathName; *Ptr; Ptr ++);
 		*Ptr ++ = '.';
@@ -187,21 +205,21 @@ gchar *libutils_get_pathname_with_new_ext (gchar *PathName, gchar *NewExt)
 		Ptr ++;
 	}
 	strcpy (Ptr, NewExt);
-	
+
 	return (NewPathName);
 }
 // RENVOIE TRUE SI LE FICHIER EXISTE SINON FALSE
-// 
+//
 gboolean libutils_test_file_with_new_ext_exist (gchar *PathName, gchar *NewExt)
 {
 	gchar		*NewPathName = libutils_get_pathname_with_new_ext (PathName, NewExt);
 	gboolean	BoolFileExist;
-	
+
 	BoolFileExist = libutils_test_file_exist (NewPathName);
-	
+
 	g_free (NewPathName);
 	NewPathName = NULL;
-	
+
 	return (BoolFileExist);
 }
 // TRUE SI LE DOSSIER EXISTE SINON FALSE
@@ -215,16 +233,16 @@ gboolean libutils_test_dir_exist (gchar *File)
 	return (g_file_test (File, G_FILE_TEST_IS_DIR));
 }
 // AFFICHE L ICONE A GAUCHE DANS LA BARRE DE TITRE
-// 
+//
 gchar *libutils_get_pathname_pixmaps (gchar *p_name_pixmap)
 {
 	gchar *LineCommand = NULL;
-	
+
 	LineCommand = xdg_search_data_xdg( p_name_pixmap );
 	return (LineCommand);
 }
 // AFFICHE L ICONE A GAUCHE DANS LA BARRE DE TITRE
-// 
+//
 void libutils_set_default_icone_to_win (GtkWidget *win)
 {
 	gchar     *LineCommand = NULL;
@@ -243,18 +261,18 @@ void libutils_set_default_icone_to_win (GtkWidget *win)
 }
 // Execute WHICH Name_Prg et si 'gchar **Pathname_Prg' est non null retourne le resultat
 //	gchar *g_find_program_in_path( const gchar *program );
-// 
+//
 gboolean libutils_find_file (gchar *p_find_file)
 {
 	gchar      *PathName = NULL;
-	
+
 	if( NULL != p_find_file ) {
 		if( NULL != (PathName = g_find_program_in_path( p_find_file ))) {
 			g_free( PathName );	PathName = NULL;
 			return( TRUE );
 		}
 	}
-	
+
 	return( FALSE );
 }
 /* utils_hexa_to_int : convertit en entier la chaine pointee par 'gchar *Ptr_Hexa' en hexa
@@ -299,7 +317,7 @@ gint libutils_hexa_to_int (gchar *Ptr_Hexa)
 	return (Gint_Ret);
 }
 // SUPPRESSION SIMPLE ALLOC POINTEE PAR LE GLIST ANSI QUE LE GLIST
-// 
+//
 GList *libutils_remove_glist (GList *New)
 {
 	GList *list = NULL;
@@ -321,7 +339,7 @@ GList *libutils_remove_glist (GList *New)
 	return ((GList *)NULL);
 }
 // SUPPRESSION SIMPLE ALLOC POINTEE PAR LE GSLIST ANSI QUE LE GSLIST
-// 
+//
 GSList *libutils_remove_gslist (GSList *New)
 {
 	GSList *gslist = NULL;
@@ -340,7 +358,7 @@ GSList *libutils_remove_gslist (GSList *New)
 	return ((GSList *)NULL);
 }
 // RETOURNE LA TAILLE DU FICHIER EN OCTETS
-// 
+//
 size_t libutils_get_size_file (gchar *PathName)
 {
 	FILE   *fp;
@@ -354,11 +372,11 @@ size_t libutils_get_size_file (gchar *PathName)
 	return (size);
 }
 // Ecriture de datas sur disk, recuperation puis effacement du fichier
-// 
+//
 void libutils_add_datas_on_disk (gchar *data)
 {
 	FILE *fp = NULL;
-	
+
 	fp = fopen ("/tmp/data_xcfa.txt", "a");
 	fprintf (fp, "%s", data);
 	fclose (fp);
@@ -368,7 +386,7 @@ gchar *libutils_get_datas_on_disk (void)
 	FILE   *fp = NULL;
 	gchar  *buf = NULL;
 	size_t  size;
-	
+
 	size = libutils_get_size_file ("/tmp/data_xcfa.txt");
 	buf = (gchar *)g_malloc0 (sizeof(gchar) * (size + 10));
 	if ((fp = fopen ("/tmp/data_xcfa.txt", "r")) != NULL) {
@@ -378,19 +396,19 @@ gchar *libutils_get_datas_on_disk (void)
 		g_free (buf);
 		buf = NULL;
 	}
-	
+
 	g_unlink ("/tmp/data_xcfa.txt");
 
 	return ((gchar  *)buf);
 }
 // TRUE SI ECRITURE OK SINON FALSE
-// 
+//
 gboolean libutils_test_write (gchar *path)
 {
 	gboolean  BoolWriteOk = FALSE;
 	FILE     *fp = NULL;
 	gchar    *str = NULL;
-	
+
 	if (path[ 0 ] == '/' && path[ 1 ] != '\0') {
 		str = g_strdup_printf ("%s/xcfa_tst_write.txt", path);
 		fp = fopen (str, "w");
@@ -402,11 +420,11 @@ gboolean libutils_test_write (gchar *path)
 		g_free (str);
 		str = NULL;
 	}
-	
+
 	return (BoolWriteOk);
 }
 // INIT PIXBUF
-// 
+//
 GdkPixbuf *libutils_init_pixbufs (gchar *NameFilePixbuf)
 {
 	GdkPixbuf *NewPixbuf = NULL;
@@ -429,20 +447,20 @@ GdkPixbuf *libutils_init_pixbufs (gchar *NameFilePixbuf)
 
 	return (NewPixbuf);
 }
-// 
+//
 // typedef enum {
 // 	TYPE_ALL_FILE = 0,
 // 	TYPE_WAV_FILE,
 // 	TYPE_MP3_OGG_FILE,
-// 	TYPE_TAG_FILE 
+// 	TYPE_TAG_FILE
 // } TYPE_FILE;
-// 
+//
 gint libutils_get_first_line_is_selected( GtkTreeSelection *AdrLine, GtkTreeModel *AdrTreeModel )
 {
 	gboolean	valid;
 	GtkTreeIter	iter;
 	gint		Cpt = -1;
-	
+
 	if (NULL != AdrLine && NULL != AdrTreeModel ) {
 		valid = gtk_tree_model_get_iter_first( AdrTreeModel, &iter );
 		while (valid) {
@@ -456,20 +474,20 @@ gint libutils_get_first_line_is_selected( GtkTreeSelection *AdrLine, GtkTreeMode
 	}
 	return( -1 );
 }
-// 
-// 
+//
+//
 gchar *libutils_get_name_without_ext_with_amp( gchar *p_PathNameFile )
 {
 	gchar *NewName = g_strnfill (strlen(p_PathNameFile) * 4, '\0');
 	gchar *NewPtr = NewName;
 	gchar *NameRet = NULL;
 	gchar *ptr = NULL;
-	
+
 	// POINTEUR SUR LE DEBUT DU NOM REEL
 	if (NULL != (ptr = strrchr (p_PathNameFile, '/')))
 		ptr ++;
 	else	ptr = p_PathNameFile;
-	
+
 	// COPIE DE p_PathNameFile VERS NewName
 	while (*ptr) {
 		if (*ptr == '&') {
@@ -483,7 +501,7 @@ gchar *libutils_get_name_without_ext_with_amp( gchar *p_PathNameFile )
 			*NewPtr ++ = *ptr ++;
 		}
 	}
-	
+
 	// DUPLIQUER NewName VERS name
 	NameRet = g_strdup (NewName);
 	g_free (NewName);
@@ -494,18 +512,18 @@ gchar *libutils_get_name_without_ext_with_amp( gchar *p_PathNameFile )
 
 	return ((gchar *)NameRet);
 }
-// 
-// 
+//
+//
 gchar *libutils_get_name_without_ext( gchar *p_PathNameFile )
 {
 	gchar *NewName = NULL;
 	gchar *Ptr = NULL;
-	
+
 	// POINTEUR SUR LE DEBUT DU NOM REEL
 	if( NULL != (Ptr = strrchr (p_PathNameFile, '/' )))
 		Ptr ++;
 	else	Ptr = p_PathNameFile;
-	
+
 	// COPIE
 	NewName = g_strdup( Ptr );
 
@@ -514,12 +532,12 @@ gchar *libutils_get_name_without_ext( gchar *p_PathNameFile )
 
 	return( (gchar *)NewName );
 }
-// 
+//
 // RETOURNE LE NOMBRE DE PROCESSUS ACTIF POUR: p_NameFile
 // EX:
 //	if( libutils_getNbProcess( "xcfa" ) > 1 )
 //	if( libutils_getNbProcess( "tm" ) > 1 )
-// 
+//
 gint libutils_getNbProcess( gchar *p_NameFile )
 {
 	size_t 		SizeFile;
@@ -530,30 +548,30 @@ gint libutils_getNbProcess( gchar *p_NameFile )
 	gint		Cpt = 0;
 	gchar		*CommandLine = NULL;
 	gchar		*PathNameFile = NULL;
-		
+
 	if( TRUE == libutils_find_file( "pidof" ) ) {
-		
+
 		PathNameFile = g_strdup_printf( "/tmp/process_%s", p_NameFile );
 		CommandLine  = g_strdup_printf( "pidof %s > %s", p_NameFile, PathNameFile );
 		system( CommandLine );
 		g_free( CommandLine );
 		CommandLine = NULL;
 		// g_print( "getpid(void) = %d\n", getpid() );
-	
+
 		if(( SizeFile = libutils_get_size_file( PathNameFile )) > 0 ) {
 			if( NULL != ( fp = fopen( PathNameFile, "r" ))) {
-			
+
 				Buffer = (gchar *)g_malloc0( sizeof(gchar) * ( SizeFile +10 ));
 				SizeFile = fread( Buffer, SizeFile, 1, fp );
 				fclose( fp );
-			
+
 				LarrbufLine = g_strsplit( Buffer, "\n", 0 );
 				g_free( Buffer );
 				Buffer = NULL;
-			
+
 				LarrbufWord = g_strsplit( LarrbufLine[ 0 ], " ", 0 );
 				for( Cpt = 0; LarrbufWord[ Cpt ]; Cpt++ );
-			
+
 				g_strfreev( LarrbufWord );
 				LarrbufWord = NULL;
 				g_strfreev( LarrbufLine );
@@ -563,23 +581,23 @@ gint libutils_getNbProcess( gchar *p_NameFile )
 		g_unlink( PathNameFile );
 		g_free( PathNameFile );
 		PathNameFile = NULL;
-		
+
 	}
-	
+
 	return( Cpt );
 }
-// 
-// 
+//
+//
 gchar *libutils_string_toupper( gchar *p_str )
 {
 	gchar	*Str = g_strdup( p_str );
 	gchar	*Ptr = Str;
-	
+
 	while( Ptr && *Ptr ) {
 		*Ptr = g_ascii_toupper( *Ptr );
 		Ptr ++;
 	}
-	
+
 	return( Str );
 }
 
