@@ -9,17 +9,17 @@
  *  GNU General Public License
  *
  *  This file is part of XCFA.
- * 
+ *
  *  XCFA is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  at your option) any later version.
- * 
+ *
  *  XCFA is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- * 
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,20 +35,20 @@ typedef struct {
 	gchar			*Artist;				// %a
 	gchar			*Title;					// %d
 	gchar			*Number;				// %c
-	gint			 IntNumber;				// 
+	gint			 IntNumber;				//
 	gchar			*Genre;					// %g
-	gint			 IntGenre;				// 
+	gint			 IntGenre;				//
 	gchar			*Year;					// %e
-	gint			 IntYear;				// 
-	gchar			*Comment;				// 
-	gchar			*Description;				// 
+	gint			 IntYear;				//
+	gchar			*Comment;				//
+	gchar			*Description;				//
 } TAGS;
 
-// 
+//
 // ---------------------------------------------------------------------------
 //  I N F O _
 // ---------------------------------------------------------------------------
-// 
+//
 
 typedef struct {
 	gint			 level;					// Niveau en dBFS
@@ -58,14 +58,14 @@ typedef struct {
 typedef struct {
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	gchar			*hertz;					// 
+	gchar			*hertz;					//
 	TAGS			*tags;					// Tags
 } INFO_M4A;
 
 typedef struct {
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	gchar			*hertz;					// 
+	gchar			*hertz;					//
 	TAGS			*tags;					// Tags
 } INFO_AAC;
 
@@ -81,7 +81,7 @@ typedef struct {
 	gchar			*NewBits;				// Nouvelle valeur
 	gboolean		 BoolConv;				// TRUE si nouvelles valeurs differenetes de anciennes valeurs
 	TAGS			*tags;					// Tags
-	LEVEL_DBFS		 LevelDbfs;				// 
+	LEVEL_DBFS		 LevelDbfs;				//
 } INFO_WAV;
 
 typedef enum {								// type:     bitrate:
@@ -92,22 +92,22 @@ typedef enum {								// type:     bitrate:
 } MPEG_IS;
 
 typedef struct {
-	gchar			*bitrate;				// 
+	gchar			*bitrate;				//
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	MPEG_IS			 mpeg_is;				// 
-	gchar			*size;					// 
+	MPEG_IS			 mpeg_is;				//
+	gchar			*size;					//
 	TAGS			*tags;					// Tags
-	LEVEL_DBFS		 LevelDbfs;				// 
+	LEVEL_DBFS		 LevelDbfs;				//
 } INFO_MP3;
 
 typedef struct {
-	gchar			*Channels;				// 
-	gchar			*Rate;					// 
-	gchar			*Nominal_bitrate;			// 
+	gchar			*Channels;				//
+	gchar			*Rate;					//
+	gchar			*Nominal_bitrate;			//
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	gchar			*size;					// 
+	gchar			*size;					//
 	TAGS			*tags;					// Tags
 	LEVEL_DBFS		 LevelDbfs;				// Datas du dBFS
 } INFO_OGG;
@@ -143,21 +143,21 @@ typedef struct {
 	TAGS			*tags;					// Tags
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	gchar			*size;					// 
+	gchar			*size;					//
 } INFO_SHN;
 
 typedef struct {
 	TAGS			*tags;					// Tags
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	gchar			*size;					// 
+	gchar			*size;					//
 } INFO_APE;
 
 typedef struct {
 	TAGS			*tags;					// Tags
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	gchar			*size;					// 
+	gchar			*size;					//
 } INFO_WAVPACK;
 
 typedef struct {
@@ -166,7 +166,7 @@ typedef struct {
 
 /*
 	M P 3
-	
+
 	TYPE:	ABR
 	DEBIT:	32 40 48 56 64 80 96 112 128 160 192 224 320
 	MODE:	Defaut / Stereo / Join Stereo / Forced Join Stereo / Duo Channels / Mono
@@ -185,7 +185,7 @@ typedef struct {
 
 	O G G
 
-	DEBIT:		45  kbit/s / 64  kbit/s / 80  kbit/s / 96  kbit/s / 112  kbit/s / 128  kbit/s / 160  kbit/s / 192  kbit/s / 224  kbit/s / 256  kbit/s / 320  kbit/s / 
+	DEBIT:		45  kbit/s / 64  kbit/s / 80  kbit/s / 96  kbit/s / 112  kbit/s / 128  kbit/s / 160  kbit/s / 192  kbit/s / 224  kbit/s / 256  kbit/s / 320  kbit/s /
 			Qualite -1 -Moins bonne qualite / Qualite  0 / Qualite  1 / Qualite  2 / Qualite  3 -Defaut / Qualite  4 / Qualite  5 / Qualite  6 / Qualite  7 / Qualite  8 / Qualite  9 / Qualite  10 -Meilleure qualite
 	MANAGED:	Oui / Non
 	DOWNMIX:	Mono force / Stereo
@@ -201,11 +201,11 @@ typedef struct {
 	gchar			*Bitrate;				// Le bitrate actuel
 } CONV_FIC_MP3OGG;
 
-// 
+//
 // ---------------------------------------------------------------------------
 //  F I C    W A V
 // ---------------------------------------------------------------------------
-// 
+//
 
 typedef struct {
 	gchar			*Path;					// Path du fichier source
@@ -215,11 +215,11 @@ typedef struct {
 	gchar			*NameDest;				// Copie vers la destination
 } CONV_FIC_WAV;
 
-// 
+//
 // ---------------------------------------------------------------------------
 //  F I C
 // ---------------------------------------------------------------------------
-// 
+//
 
 typedef enum {
 	FILE_IS_NONE = 0,
@@ -346,52 +346,52 @@ enum {
 
 
 typedef struct {
-	ETAT_PLAY_FILE		 EtatPlay;				// 
+	ETAT_PLAY_FILE		 EtatPlay;				//
 	gchar			*name_dest;				// Nom du fichier de destination sans le path ni l'extension
-	gchar			*dest_flac;				// 
-	gchar			*dest_wav;				// 
-	gchar			*dest_mp3;				// 
-	gchar			*dest_ogg;				// 
-	gchar			*dest_m4a;				// 
-	gchar			*dest_aac;				// 
-	gchar			*dest_mpc;				// 
-	gchar			*dest_ape;				// 
-	gchar			*dest_wavpack;				// 
-	gchar			*dest_wavpack_md5;			// 
-	gchar			*tmp_flac;				// 
-	gchar			*tmp_wav;				// 
+	gchar			*dest_flac;				//
+	gchar			*dest_wav;				//
+	gchar			*dest_mp3;				//
+	gchar			*dest_ogg;				//
+	gchar			*dest_m4a;				//
+	gchar			*dest_aac;				//
+	gchar			*dest_mpc;				//
+	gchar			*dest_ape;				//
+	gchar			*dest_wavpack;				//
+	gchar			*dest_wavpack_md5;			//
+	gchar			*tmp_flac;				//
+	gchar			*tmp_wav;				//
 	gchar			*tmp_sox;				// wav to wav
 	gchar			*tmp_sox_24;				// wav to wav
-	gchar			*tmp_mp3;				// 
-	gchar			*tmp_ogg;				// 
-	gchar			*tmp_m4a;				// 
-	gchar			*tmp_aac;				// 
-	gchar			*tmp_shn;				// 
-	gchar			*tmp_wma;				// 
-	gchar			*tmp_rm;				// 
-	gchar			*tmp_dts;				// 
-	gchar			*tmp_aiff;				// 
-	gchar			*tmp_mpc;				// 
-	gchar			*tmp_ape;				// 
-	gchar			*tmp_wavpack;				// 
-	gchar			*tmp_wavpack_md5;			// 
-	gchar			*tmp_ac3;				// 
-	gboolean		 BoolEtatConv [ ETAT_BOOL_TOTAL ];	// 
-	ETAT_CONV_FILE		 Etat_Flac;				// 
-	ETAT_CONV_FILE		 Etat_Wav;				// 
-	ETAT_CONV_FILE		 Etat_Mp3;				// 
-	ETAT_CONV_FILE		 Etat_Ogg;				// 
-	ETAT_CONV_FILE		 Etat_m4a;				// 
-	ETAT_CONV_FILE		 Etat_aac;				// 
-	ETAT_CONV_FILE		 Etat_Mpc;				// 
-	ETAT_CONV_FILE		 Etat_Ape;				// 
-	ETAT_CONV_FILE		 Etat_wavpack;				// 
-	gboolean		 BoolNewString;				// 
-		
+	gchar			*tmp_mp3;				//
+	gchar			*tmp_ogg;				//
+	gchar			*tmp_m4a;				//
+	gchar			*tmp_aac;				//
+	gchar			*tmp_shn;				//
+	gchar			*tmp_wma;				//
+	gchar			*tmp_rm;				//
+	gchar			*tmp_dts;				//
+	gchar			*tmp_aiff;				//
+	gchar			*tmp_mpc;				//
+	gchar			*tmp_ape;				//
+	gchar			*tmp_wavpack;				//
+	gchar			*tmp_wavpack_md5;			//
+	gchar			*tmp_ac3;				//
+	gboolean		 BoolEtatConv [ ETAT_BOOL_TOTAL ];	//
+	ETAT_CONV_FILE		 Etat_Flac;				//
+	ETAT_CONV_FILE		 Etat_Wav;				//
+	ETAT_CONV_FILE		 Etat_Mp3;				//
+	ETAT_CONV_FILE		 Etat_Ogg;				//
+	ETAT_CONV_FILE		 Etat_m4a;				//
+	ETAT_CONV_FILE		 Etat_aac;				//
+	ETAT_CONV_FILE		 Etat_Mpc;				//
+	ETAT_CONV_FILE		 Etat_Ape;				//
+	ETAT_CONV_FILE		 Etat_wavpack;				//
+	gboolean		 BoolNewString;				//
+
 } CONV_FIC;
 
 typedef enum {
-	STRUCT_NO_REMOVE = 0,						// 
+	STRUCT_NO_REMOVE = 0,						//
 	STRUCT_ALL_REMOVE,						// Remove in treeview ALL FILE
 	STRUCT_WAV_REMOVE_WAV,						// Remove in treeview WAV
 	STRUCT_MP3OGG_REMOVE,						// Remove in treeview MP3OGG
@@ -399,17 +399,17 @@ typedef enum {
 } TYPE_REMOVE_STRUCT;
 
 
-// 
+//
 // ---------------------------------------------------------------------------
-//  F I C 
+//  F I C
 // ---------------------------------------------------------------------------
-// 
+//
 
 
 typedef struct {
 	gchar			*namefile;				// Nom complet du fichier
-	gchar			*NameFileCopyFromNormalizate;		// 
-	gchar			*NameDest;				// Nom de la destination									
+	gchar			*NameFileCopyFromNormalizate;		//
+	gchar			*NameDest;				// Nom de la destination
 	TYPE_FILE_IS		 type_infosong_file_is;			// Type du fichier
 	void 			*info;					// En fonction du type de fichier pointeur sur INFO_xxx
 	ETAT_TRASH_FILE		 EtatTrash;				// Etat pour la poubelle
@@ -432,24 +432,22 @@ typedef struct {
 	TYPE_REMOVE_STRUCT	 BoolRemove;				// TRUE si suppression de la liste sinon FALSE
 
 	// MP3: DEBIT MODE
-	gint			Mp3_Debit;				// 
-	gint			Mp3_Mode;				// 
+	gint			Mp3_Debit;				//
+	gint			Mp3_Mode;				//
 	// OGG: DEBIT MANAGED DOWNMIX
-	gint			Ogg_Debit;				// 
-	gint			Ogg_Managed;				// 
-	gint			Ogg_Downmix;				// 
-	gboolean		BoolChanged;				// 
-	
-	gboolean		BoolConvertActivate;			// 
+	gint			Ogg_Debit;				//
+	gint			Ogg_Managed;				//
+	gint			Ogg_Downmix;				//
+	gboolean		BoolChanged;				//
 } DETAIL;
 
 extern GList *entetefile;						// pointeur sur DETAIL
 
-// 
+//
 // ---------------------------------------------------------------------------
 //  FILE.C
 // ---------------------------------------------------------------------------
-// 
+//
 typedef struct {
 	GtkComboBox		*AdrComboboxNormalise;			// Adresse
 	GtkSpinButton		*AdrSpinbuttonNormalise;		// Adresse
@@ -496,12 +494,12 @@ typedef struct {
 	GdkPixbuf		*Pixbuf_rpg_album;			// rpg_album.png
 	GdkPixbuf		*Pixbuf_rpg_effacer;			// rpg_effacer.png
 	GdkPixbuf		*Pixbuf_rpg_wait;			// rpg_wait.png
-	
+
 	GdkPixbuf		*Pixbuf_norm_fix;			// norm_fix.png
 	GdkPixbuf		*Pixbuf_norm_mix;			// norm_mix.png
 	GdkPixbuf		*Pixbuf_norm_peak;			// norm_peak.png
 	GdkPixbuf		*Pixbuf_norm_wait;			// norm_wait.png
-	
+
 } VAR_FILE;
 
 extern VAR_FILE var_file;
@@ -522,7 +520,7 @@ typedef struct {
 	GtkTreeViewColumn	*Adr_ColumnFileWavNewVoie;
 	GtkTreeViewColumn	*Adr_ColumnFileWavNewBits;
 	GtkTreeViewColumn	*Adr_ColumnFileWavName;
-	
+
 } VAR_FILE_WAV;
 
 extern VAR_FILE_WAV var_file_wav;
@@ -595,11 +593,11 @@ typedef enum {
 	FILEWAV_QUANTIFICATION_CELL
 } TYPE_SET_FROM_POPUP_FILE;
 
-// 
+//
 // ---------------------------------------------------------------------------
 //  FILE.C
 // ---------------------------------------------------------------------------
-// 
+//
 gchar		*file_get_time( DETAIL *detail );
 void		file_scrolledwindow_file_realize( GtkWidget *widget );
 void		file_set_flag_buttons( void );
@@ -616,76 +614,76 @@ gchar		*file_get_pathname_dest( DETAIL *detail, gchar *NewExt );
 gchar		*file_get_size( DETAIL *detail );
 void		on_file_button_del_file_clicked( GtkButton *button, gpointer user_data );
 void		file_from_popup( TYPE_SET_FROM_POPUP_FILE TypeSetFromPopup, DETAIL *detail, TYPE_FILE_IS TypeFileIs );
-// 
+//
 // ---------------------------------------------------------------------------
 //  FILE_SCAN_DB.C
 // ---------------------------------------------------------------------------
-// 
+//
 void		FileScanDB_action( gboolean BoolAllScan );
-// 
+//
 // ---------------------------------------------------------------------------
 //  FILE_ANALYZE.C
 // ---------------------------------------------------------------------------
-// 
+//
 #include "fileselect.h"
 
 void		fileanalyze_remove_entetefile_detail( void );
 void		fileanalyze_remove_entetefile( void );
 void		fileanalyze_add_file_to_treeview( TYPE_FILESELECTION p_TypeFileselection, GSList *p_list );
 gboolean	fileanalyze_exist( DETAIL *detail, gchar *NewExt );
-// 
+//
 // ---------------------------------------------------------------------------
 //  FILE_CONV.C
 // ---------------------------------------------------------------------------
-// 
+//
 void		fileconv_action( void );
-// 
+//
 // ---------------------------------------------------------------------------
 //  FILE_MP3OGG.C
 // ---------------------------------------------------------------------------
-// 
+//
 void		FileMp3Ogg_set_flag_buttons( void );
 void		FileMp3Ogg_affiche_glist( void );
 gboolean	FileMp3Ogg_del_file_clicked( void );
 void		FileMp3Ogg_change_parameters( void );
 // void		FileMp3Ogg_update_newbitrate( TYPE_FILE_IS p_TypeFileIs );
 void		FileMp3Ogg_update_newbitrate( TYPE_FILE_IS p_TypeFileIs, gint p_debit, gint p_mode_managed, gint p_downmix );
-// 
+//
 // ---------------------------------------------------------------------------
 //  FILE_MP3OGG_CONV.C
 // ---------------------------------------------------------------------------
-// 
+//
 void		filemp3oggconv_apply_regul_mp3ogg_by_conv( void );
-// 
+//
 // ---------------------------------------------------------------------------
 //  FILE_WAV.C
 // ---------------------------------------------------------------------------
-// 
+//
 void		FileWav_affiche_glist( void );
 void		FileWav_change_parameters( void );
 void		FileWav_set_flag_buttons( void );
 void		FileWav_from_popup( TYPE_SET_FROM_POPUP_FILE TypeSetFromPopup, DETAIL *detail, gint freq, gint voie, gint bits );
-// 
+//
 // ---------------------------------------------------------------------------
 //  FILE_TAGS.C
 // ---------------------------------------------------------------------------
-// 
+//
 void		FileTags_affiche_glist( void );
 gboolean	FileWav_del_file_clicked( void );
 gboolean	FileTags_del_file_clicked( void );
 void		FileTags_appliquer_clicked( void );
 void		FileTags_set_flag_buttons( void );
-// 
+//
 // ---------------------------------------------------------------------------
 //  FILE_WAV_CONV.C
 // ---------------------------------------------------------------------------
-// 
+//
 void		filewavconv_apply( void );
-// 
+//
 // ---------------------------------------------------------------------------
 //  FILE_ACTION.C
 // ---------------------------------------------------------------------------
-// 
+//
 typedef enum {
 	TYPE_REPLAYGAINCLEAR = 0,
 	TYPE_NORMALISE,
@@ -696,11 +694,11 @@ typedef enum {
 
 void		fileaction_choice( void );
 void		fileaction_set_end( FILEACTION_TYPE FileActionType );
-// 
+//
 // ---------------------------------------------------------------------------
 //  FILE_LC.C
 // ---------------------------------------------------------------------------
-// 
+//
 #include "conv.h"
 
 typedef struct {
@@ -715,9 +713,9 @@ typedef struct {
 	gchar		*PtrStrBitrate;
 } PARAM_FILELC;
 
-// 
+//
 // Allocate Tab Args
-// 
+//
 gchar		**filelc_AllocTabArgs( void );
 gchar		**filelc_RevoveTab( gchar **p_PtrTabArgs );
 // gint		filelc_get_command_line_remove( void );
@@ -726,11 +724,11 @@ gchar		**filelc_get_command_line( PARAM_FILELC *param_filelc );
 void		filelc_get_command_line_extract( PARAM_FILELC *param_filelc );
 GList		*filelc_remove_glist( GList *New );
 void		filelc_get_command_line_extract_elem( gint Elem, gchar *Dev, gchar *Dest );
-// 
+//
 // ---------------------------------------------------------------------------
 //  FILE_TRASH.C
 // ---------------------------------------------------------------------------
-// 
+//
 void		filetrash_action( void );
 gboolean	filetrash_ok( void );
 gboolean	filetrash_move_to_trash( gchar *Name );
