@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2012 by Claude Bulin
+ *  copyright : (C) 2003 - 2013 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -94,8 +94,220 @@ GList *entetefile = NULL;				/* pointeur sur DETAIL */
 
 
 
+// SUPPRESSION DU CONTENU DE entetefile SI BoolRemove==TRUE ET DU GLIST
+// 
+void fileanalyze_remove_entetefile_detail( void )
+{
+	GList		*list = NULL;
+	DETAIL		*detail = NULL;
+	
+	if( NULL != ( list = g_list_first( entetefile ))) {
+		while (list) {
+			if( NULL != (detail = (DETAIL *)list->data) ) {
+			
+				if( TRUE == detail->BoolRemove ) {
+				
+					if( NULL != detail->namefile ) {
+						g_free( detail->namefile );
+						detail->namefile = NULL;
+					}
+					if( NULL != detail->NameDest ) {
+						g_free( detail->NameDest );
+						detail->NameDest = NULL;
+					}
+					if( NULL != detail->NameFileCopyFromNormalizate ) {
+						g_free( detail->NameFileCopyFromNormalizate );
+						detail->NameFileCopyFromNormalizate = NULL;
+					}
+				
+					if (detail->type_infosong_file_is == FILE_IS_FLAC) {
+						INFO_FLAC *info = (INFO_FLAC *)detail->info;
+						detail->info = (INFO_FLAC *)tagsflac_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_WAV) {
+						INFO_WAV *info = (INFO_WAV *)detail->info;
+						// LevelDbfs    = info->LevelDbfs;
+						detail->info = (INFO_WAV *)tagswav_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_MP3) {
+						INFO_MP3 *info = (INFO_MP3 *)detail->info;
+						// LevelDbfs    = info->LevelDbfs;
+						detail->info = (INFO_MP3 *)tagsmp3_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_OGG) {
+						INFO_OGG *info = (INFO_OGG *)detail->info;
+						// LevelDbfs    = info->LevelDbfs;
+						detail->info = (INFO_OGG *)tagsogg_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_M4A) {
+						INFO_M4A *info = (INFO_M4A *)detail->info;
+						detail->info = (INFO_M4A *)tagsm4a_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_VID_M4A) {
+						INFO_M4A *info = (INFO_M4A *)detail->info;
+						detail->info = (INFO_M4A *)tagsm4a_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_AAC) {
+						INFO_AAC *info = (INFO_AAC *)detail->info;
+						detail->info = (INFO_AAC *)tagsaac_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_SHN) {
+						INFO_SHN *info = (INFO_SHN *)detail->info;
+						detail->info = (INFO_SHN *)tagsshn_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_WMA) {
+						INFO_WMA *info = (INFO_WMA *)detail->info;
+						detail->info = (INFO_WMA *)tagswma_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_RM) {
+						INFO_RM *info = (INFO_RM *)detail->info;
+						detail->info = (INFO_RM *)tagsrm_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_DTS) {
+						INFO_DTS *info = (INFO_DTS *)detail->info;
+						detail->info = (INFO_DTS *)tagsdts_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_AIFF) {
+						INFO_AIFF *info = (INFO_AIFF *)detail->info;
+						detail->info = (INFO_AIFF *)tagsaiff_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_MPC) {
+						INFO_MPC *info = (INFO_MPC *)detail->info;
+						detail->info = (INFO_MPC *)tagsmpc_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_APE) {
+						INFO_APE *info = (INFO_APE *)detail->info;
+						detail->info = (INFO_APE *)tagsape_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_WAVPACK) {
+						INFO_WAVPACK *info = (INFO_WAVPACK *)detail->info;
+						detail->info = (INFO_WAVPACK *)tagswavpack_remove_info (info);
+					}
+					else if (detail->type_infosong_file_is == FILE_IS_AC3) {
+						INFO_AC3 *info = (INFO_AC3 *)detail->info;
+						detail->info = (INFO_AC3 *)tagsac3_remove_info (info);
+					}
+			
+					g_free( detail );
+					detail = NULL;
+				}
+			}
+			list->data = NULL;
+			list = g_list_next (list);
+		}
 
-
+		g_list_free( entetefile );
+	}
+	entetefile = NULL;
+}
+// SUPPRESSION DU CONTENU DE entetefile ET DU GLIST
+// 
+void fileanalyze_remove_entetefile (void)
+{
+	GList   *list = NULL;
+	DETAIL  *detail = NULL;
+	gint	 NbList = 0;
+	
+	if( NULL != ( list = g_list_first( entetefile ))) {
+		while (list) {
+			if (NULL != (detail = (DETAIL *)list->data)) {
+			
+				// fileanalyze_remove_entetefile_detail( &detail );
+			
+				if( NULL != detail->namefile ) {
+					g_free( detail->namefile );
+					detail->namefile = NULL;
+				}
+				if( NULL != detail->NameDest ) {
+					g_free( detail->NameDest );
+					detail->NameDest = NULL;
+				}
+				if( NULL != detail->NameFileCopyFromNormalizate ) {
+					g_free( detail->NameFileCopyFromNormalizate );
+					detail->NameFileCopyFromNormalizate = NULL;
+				}
+				
+				if (detail->type_infosong_file_is == FILE_IS_FLAC) {
+					INFO_FLAC *info = (INFO_FLAC *)detail->info;
+					detail->info = (INFO_FLAC *)tagsflac_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_WAV) {
+					INFO_WAV *info = (INFO_WAV *)detail->info;
+					// LevelDbfs    = info->LevelDbfs;
+					detail->info = (INFO_WAV *)tagswav_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_MP3) {
+					INFO_MP3 *info = (INFO_MP3 *)detail->info;
+					// LevelDbfs    = info->LevelDbfs;
+					detail->info = (INFO_MP3 *)tagsmp3_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_OGG) {
+					INFO_OGG *info = (INFO_OGG *)detail->info;
+					// LevelDbfs    = info->LevelDbfs;
+					detail->info = (INFO_OGG *)tagsogg_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_M4A) {
+					INFO_M4A *info = (INFO_M4A *)detail->info;
+					detail->info = (INFO_M4A *)tagsm4a_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_VID_M4A) {
+					INFO_M4A *info = (INFO_M4A *)detail->info;
+					detail->info = (INFO_M4A *)tagsm4a_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_AAC) {
+					INFO_AAC *info = (INFO_AAC *)detail->info;
+					detail->info = (INFO_AAC *)tagsaac_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_SHN) {
+					INFO_SHN *info = (INFO_SHN *)detail->info;
+					detail->info = (INFO_SHN *)tagsshn_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_WMA) {
+					INFO_WMA *info = (INFO_WMA *)detail->info;
+					detail->info = (INFO_WMA *)tagswma_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_RM) {
+					INFO_RM *info = (INFO_RM *)detail->info;
+					detail->info = (INFO_RM *)tagsrm_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_DTS) {
+					INFO_DTS *info = (INFO_DTS *)detail->info;
+					detail->info = (INFO_DTS *)tagsdts_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_AIFF) {
+					INFO_AIFF *info = (INFO_AIFF *)detail->info;
+					detail->info = (INFO_AIFF *)tagsaiff_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_MPC) {
+					INFO_MPC *info = (INFO_MPC *)detail->info;
+					detail->info = (INFO_MPC *)tagsmpc_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_APE) {
+					INFO_APE *info = (INFO_APE *)detail->info;
+					detail->info = (INFO_APE *)tagsape_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_WAVPACK) {
+					INFO_WAVPACK *info = (INFO_WAVPACK *)detail->info;
+					detail->info = (INFO_WAVPACK *)tagswavpack_remove_info (info);
+				}
+				else if (detail->type_infosong_file_is == FILE_IS_AC3) {
+					INFO_AC3 *info = (INFO_AC3 *)detail->info;
+					detail->info = (INFO_AC3 *)tagsac3_remove_info (info);
+				}
+			
+				detail = list->data = NULL;
+			
+				NbList ++;
+			}
+			list = g_list_next (list);
+		}
+		g_list_free( entetefile );
+		entetefile = NULL;
+	}
+	
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print ("\tRemove: %d\n", NbList);
+}
 // 
 // 
 gboolean fileanalyze_exist (DETAIL *detail, gchar *NewExt)
@@ -110,105 +322,6 @@ gboolean fileanalyze_exist (DETAIL *detail, gchar *NewExt)
 	Name = NULL;
 	return (bool_exist);
 }
-// SUPPRESSION DU CONTENU DE entetefile ET DU GLIST
-// 
-void fileanalyze_remove_entetefile (void)
-{
-	GList   *list = NULL;
-	DETAIL  *detail = NULL;
-	gint	 NbList = 0;
-	
-	list = g_list_first (entetefile);
-	while (list) {
-		if (NULL != (detail = (DETAIL *)list->data)) {
-			
-			if( NULL != detail->namefile ) {
-				g_free( detail->namefile );
-				detail->namefile = NULL;
-			}
-			if( NULL != detail->NameDest ) {
-				g_free( detail->NameDest );
-				detail->NameDest = NULL;
-			}
-				
-			if (detail->type_infosong_file_is == FILE_IS_FLAC) {
-				INFO_FLAC *info = (INFO_FLAC *)detail->info;
-				detail->info = (INFO_FLAC *)tagsflac_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_WAV) {
-				INFO_WAV *info = (INFO_WAV *)detail->info;
-				// LevelDbfs    = info->LevelDbfs;
-				detail->info = (INFO_WAV *)tagswav_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_MP3) {
-				INFO_MP3 *info = (INFO_MP3 *)detail->info;
-				// LevelDbfs    = info->LevelDbfs;
-				detail->info = (INFO_MP3 *)tagsmp3_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_OGG) {
-				INFO_OGG *info = (INFO_OGG *)detail->info;
-				// LevelDbfs    = info->LevelDbfs;
-				detail->info = (INFO_OGG *)tagsogg_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_M4A) {
-				INFO_M4A *info = (INFO_M4A *)detail->info;
-				detail->info = (INFO_M4A *)tagsm4a_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_VID_M4A) {
-				INFO_M4A *info = (INFO_M4A *)detail->info;
-				detail->info = (INFO_M4A *)tagsm4a_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_AAC) {
-				INFO_AAC *info = (INFO_AAC *)detail->info;
-				detail->info = (INFO_AAC *)tagsaac_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_SHN) {
-				INFO_SHN *info = (INFO_SHN *)detail->info;
-				detail->info = (INFO_SHN *)tagsshn_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_WMA) {
-				INFO_WMA *info = (INFO_WMA *)detail->info;
-				detail->info = (INFO_WMA *)tagswma_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_RM) {
-				INFO_RM *info = (INFO_RM *)detail->info;
-				detail->info = (INFO_RM *)tagsrm_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_DTS) {
-				INFO_DTS *info = (INFO_DTS *)detail->info;
-				detail->info = (INFO_DTS *)tagsdts_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_AIFF) {
-				INFO_AIFF *info = (INFO_AIFF *)detail->info;
-				detail->info = (INFO_AIFF *)tagsaiff_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_MPC) {
-				INFO_MPC *info = (INFO_MPC *)detail->info;
-				detail->info = (INFO_MPC *)tagsmpc_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_APE) {
-				INFO_APE *info = (INFO_APE *)detail->info;
-				detail->info = (INFO_APE *)tagsape_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_WAVPACK) {
-				INFO_WAVPACK *info = (INFO_WAVPACK *)detail->info;
-				detail->info = (INFO_WAVPACK *)tagswavpack_remove_info (info);
-			}
-			else if (detail->type_infosong_file_is == FILE_IS_AC3) {
-				INFO_AC3 *info = (INFO_AC3 *)detail->info;
-				detail->info = (INFO_AC3 *)tagsac3_remove_info (info);
-			}
-			
-			detail = list->data = NULL;
-			
-			NbList ++;
-		}
-		list = g_list_next (list);
-	}
-	entetefile = libutils_remove_glist (entetefile);
-	if( TRUE == OptionsCommandLine.BoolVerboseMode )
-		g_print ("\tRemove: %d\n", NbList);
-}
 // RECHERCHE RECURSIVE DES FICHIERS
 // INDIQUE LE NOMBRE TOTAL DANS: VarAnalyze.RecTotalFile
 // 
