@@ -366,10 +366,10 @@ void filemp3oggconv_set_flags_before_conversion (void)
 	DETAIL          *detail = NULL;
 	CONV_FIC_MP3OGG	*PConvMp3Ogg;
 
-	// INIT DOSSIER TEMPORAIRE
-	if (NULL == conv.TmpRep)  {
+	// Create tmp rep
+	if( NULL == conv.TmpRep )
 		conv.TmpRep  = libutils_create_temporary_rep (Config.PathnameTMP, PATH_TMP_XCFA_AUDIOFILEMP3OGG);
-	}
+
 
 	list = g_list_first (entetefile);
 	while (list) {
