@@ -380,11 +380,10 @@ void filewavconv_set_flags_before (void)
 			detail->PConvWav = (CONV_FIC_WAV *)g_malloc0 (sizeof (CONV_FIC_WAV));
 			PConvWav = detail->PConvWav;
 			
-			// Create temporary rep
-			if (NULL == conv.TmpRep)  {
+			// Create tmp rep
+			if( NULL == conv.TmpRep )
 				conv.TmpRep  = libutils_create_temporary_rep (Config.PathnameTMP, PATH_TMP_XCFA_AUDIOFILEWAVCONV);
-			}
-	
+
 			// Nouvelles: source et destination
 			
 			// $TMP/original
