@@ -109,59 +109,61 @@ void replaygain_set_list( RPG_TYPE rpg_type, ETAT_REPLAYGAIN rpg_action)
 	ETAT_REPLAYGAIN  *PtrReplayGain = NULL;
 	gboolean          BoolList = FALSE;
 	gint		  pos;
+	gchar		**PtrTabArgs = NULL;
 	
 	if( TRUE == rpg.bool_thread_end) return;
 	
 	rpg.MessUser [ 0 ] = '\0';
 	
 	// Entete global
-	pos = filelc_get_command_line_nice ( );
+	PtrTabArgs = filelc_AllocTabArgs();
+	pos = 3;
 	
 	// Entetes particuliers
 	switch (rpg_type ) {
 	case MP3GAIN :
-		conv.ArgConv [ pos++ ] = g_strdup ("mp3gain" );
+		PtrTabArgs [ pos++ ] = g_strdup ("mp3gain" );
 		strcat( rpg.MessUser, "MP3, mp3gain"  );
 		switch (rpg_action ) {
 		case RPG_NONE :
 		case RPG_ATTENTE :
 			break;
 		case RPG_EFFACER :
-			conv.ArgConv [ pos++ ] = g_strdup ("-s" );
-			conv.ArgConv [ pos++ ] = g_strdup ("d" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-s" );
+			PtrTabArgs [ pos++ ] = g_strdup ("d" );
 			strcat( rpg.MessUser, ", EFFACER"  );
 			break;
 		case RPG_ALBUM :
-			conv.ArgConv [ pos++ ] = g_strdup ("-a" );
-			conv.ArgConv [ pos++ ] = g_strdup ("-p" );
-			conv.ArgConv [ pos++ ] = g_strdup ("-c" );
-			conv.ArgConv [ pos++ ] = g_strdup ("-f" );
-			conv.ArgConv [ pos++ ] = g_strdup ("-T" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-a" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-p" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-c" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-f" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-T" );
 			strcat( rpg.MessUser, ", ALBUM"  );
 			break;
 		case RPG_PISTE :
-			conv.ArgConv [ pos++ ] = g_strdup ("-r" );
-			conv.ArgConv [ pos++ ] = g_strdup ("-p" );
-			conv.ArgConv [ pos++ ] = g_strdup ("-c" );
-			conv.ArgConv [ pos++ ] = g_strdup ("-f" );
-			conv.ArgConv [ pos++ ] = g_strdup ("-T" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-r" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-p" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-c" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-f" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-T" );
 			strcat( rpg.MessUser, ", PISTE"  );
 			break;
 		}
 		break;
 	case METAFLAC :
-		conv.ArgConv [ pos++ ] = g_strdup ("metaflac" );
+		PtrTabArgs [ pos++ ] = g_strdup ("metaflac" );
 		strcat( rpg.MessUser, "FLAC, metaflac"  );
 		switch (rpg_action ) {
 		case RPG_NONE :
 		case RPG_ATTENTE :
 			break;
 		case RPG_EFFACER :
-			conv.ArgConv [ pos++ ] = g_strdup ("--remove-replay-gain" );
+			PtrTabArgs [ pos++ ] = g_strdup ("--remove-replay-gain" );
 			strcat( rpg.MessUser, ", EFFACER"  );
 			break;
 		case RPG_ALBUM :
-			conv.ArgConv [ pos++ ] = g_strdup ("--add-replay-gain" );
+			PtrTabArgs [ pos++ ] = g_strdup ("--add-replay-gain" );
 			strcat( rpg.MessUser, ", ALBUM"  );
 			break;
 		case RPG_PISTE :
@@ -170,18 +172,18 @@ void replaygain_set_list( RPG_TYPE rpg_type, ETAT_REPLAYGAIN rpg_action)
 		}
 		break;
 	case WVGAIN :
-		conv.ArgConv [ pos++ ] = g_strdup ("wvgain" );
+		PtrTabArgs [ pos++ ] = g_strdup ("wvgain" );
 		strcat( rpg.MessUser, "WAVPACK, wvgain"  );
 		switch (rpg_action ) {
 		case RPG_NONE :
 		case RPG_ATTENTE :
 			break;
 		case RPG_EFFACER :
-			conv.ArgConv [ pos++ ] = g_strdup ("-c" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-c" );
 			strcat( rpg.MessUser, ", EFFACER"  );
 			break;
 		case RPG_ALBUM :
-			conv.ArgConv [ pos++ ] = g_strdup ("-a" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-a" );
 			strcat( rpg.MessUser, ", ALBUM"  );
 			break;
 		case RPG_PISTE :
@@ -190,18 +192,18 @@ void replaygain_set_list( RPG_TYPE rpg_type, ETAT_REPLAYGAIN rpg_action)
 		}
 		break;
 	case VORBISGAIN :
-		conv.ArgConv [ pos++ ] = g_strdup ("vorbisgain" );
+		PtrTabArgs [ pos++ ] = g_strdup ("vorbisgain" );
 		strcat( rpg.MessUser, "OGG, vorbisgain"  );
 		switch (rpg_action ) {
 		case RPG_NONE :
 		case RPG_ATTENTE :
 			break;
 		case RPG_EFFACER :
-			conv.ArgConv [ pos++ ] = g_strdup ("-c" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-c" );
 			strcat( rpg.MessUser, ", EFFACER"  );
 			break;
 		case RPG_ALBUM :
-			conv.ArgConv [ pos++ ] = g_strdup ("-a" );
+			PtrTabArgs [ pos++ ] = g_strdup ("-a" );
 			strcat( rpg.MessUser, ", ALBUM"  );
 			break;
 		case RPG_PISTE :
@@ -232,7 +234,7 @@ void replaygain_set_list( RPG_TYPE rpg_type, ETAT_REPLAYGAIN rpg_action)
 					
 					BoolList = TRUE;
 					
-					conv.ArgConv [ pos++ ] = g_strdup (detail->namefile );
+					PtrTabArgs [ pos++ ] = g_strdup (detail->namefile );
 					
 					// Get pointer Etat Flag
 					ListEtat = g_list_append (ListEtat, &detail->Etat_ReplayGain );
@@ -245,7 +247,7 @@ void replaygain_set_list( RPG_TYPE rpg_type, ETAT_REPLAYGAIN rpg_action)
 				else if( detail->type_infosong_file_is == FILE_IS_MP3 && rpg_type == MP3GAIN ) {
 				
 					BoolList = TRUE;
-					conv.ArgConv [ pos++ ] = g_strdup (detail->namefile );
+					PtrTabArgs [ pos++ ] = g_strdup (detail->namefile );
 					
 					// Get pointer Etat Flag
 					ListEtat = g_list_append (ListEtat, &detail->Etat_ReplayGain );
@@ -258,7 +260,7 @@ void replaygain_set_list( RPG_TYPE rpg_type, ETAT_REPLAYGAIN rpg_action)
 				else if( detail->type_infosong_file_is == FILE_IS_FLAC && rpg_type == METAFLAC ) {
 					// PISTE -> NONE
 					BoolList = TRUE;
-					conv.ArgConv [ pos++ ] = g_strdup (detail->namefile );
+					PtrTabArgs [ pos++ ] = g_strdup (detail->namefile );
 					
 					// Get pointer Etat Flag
 					ListEtat = g_list_append (ListEtat, &detail->Etat_ReplayGain );
@@ -270,7 +272,7 @@ void replaygain_set_list( RPG_TYPE rpg_type, ETAT_REPLAYGAIN rpg_action)
 				// WVGAIN
 				else if( detail->type_infosong_file_is == FILE_IS_WAVPACK && rpg_type == WVGAIN ) {
 					BoolList = TRUE;
-					conv.ArgConv [ pos++ ] = g_strdup (detail->namefile );
+					PtrTabArgs [ pos++ ] = g_strdup (detail->namefile );
 					
 					// Get pointer Etat Flag
 					ListEtat = g_list_append (ListEtat, &detail->Etat_ReplayGain );
@@ -290,9 +292,9 @@ void replaygain_set_list( RPG_TYPE rpg_type, ETAT_REPLAYGAIN rpg_action)
 		// Appel au ReplayGain
 		rpg.bool_compteur = TRUE;
 		rpg.bool_etat = TRUE;
-		conv.ArgConv [ pos++ ] = NULL;
-		conv_to_convert (FALSE, REPLAYGAIN, rpg.MessUser );
-		filelc_get_command_line_remove ( );
+		PtrTabArgs [ pos++ ] = NULL;
+		conv_to_convert( PtrTabArgs, FALSE, REPLAYGAIN, rpg.MessUser );
+		PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
 		
 		rpg.bool_compteur = FALSE;
 
