@@ -9,22 +9,22 @@
  *  GNU General Public License
  *
  *  This file is part of XCFA.
- * 
+ *
  *  XCFA is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  at your option) any later version.
- * 
+ *
  *  XCFA is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- * 
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
  */
- 
- 
+
+
 #ifdef HAVE_CONFIG_H
 	#include "../config.h"
 #endif
@@ -117,11 +117,11 @@ gint tagsmp3_type_mpeg (gchar *namefile)
 	if (NULL == (gstr = GetInfo_checkmp3 (namefile))) {
 		return (-1);
 	}
-	
+
 	Lout = gstr->str;
 	for (i = 0; i < 3; i ++) {
 		if ((ptr = strstr (Lout, term[ i ]))) {
-			
+
 			/* Init la chaine de stockage */
 			for (cpt=0; cpt < MAX_STR; cpt++) str [ cpt ] = '\0';
 
@@ -156,10 +156,32 @@ gint tagsmp3_type_mpeg (gchar *namefile)
 	}
 	g_string_free (gstr, TRUE);
 	Lout = NULL;
-	
+
 	return (Ret);
 }
 
+void tagsmp3_print( gchar *p_PathNameFile, INFO_MP3 *ptrinfo )
+{
+	if( TRUE == OptionsCommandLine.BoolVerboseMode && NULL != ptrinfo ) {
+		g_print( "\n");
+		g_print ("\t%s\n", p_PathNameFile );
+		g_print( "\tptrinfo->tags->Title    = %s\n", ptrinfo->tags->Title );
+		g_print( "\tptrinfo->tags->Artist   = %s\n", ptrinfo->tags->Artist );
+		g_print( "\tptrinfo->tags->Album    = %s\n", ptrinfo->tags->Album );
+		g_print( "\tptrinfo->tags->IntYear  = %d\n", ptrinfo->tags->IntYear );
+		g_print( "\tptrinfo->tags->Year     = %s\n", ptrinfo->tags->Year );
+		g_print( "\tptrinfo->tags->Comment  = %s\n", ptrinfo->tags->Comment );
+		g_print( "\tptrinfo->tags->IntNumber= %d\n", ptrinfo->tags->IntNumber );
+		g_print( "\tptrinfo->tags->Number   = %s\n", ptrinfo->tags->Number );
+		g_print( "\tptrinfo->tags->Genre    = %s\n", ptrinfo->tags->Genre );
+		g_print( "\tptrinfo->tags->IntGenre = %d\n", ptrinfo->tags->IntGenre );
+		g_print( "\tptrinfo->time           = %s\n", ptrinfo->time );
+		g_print( "\tptrinfo->bitrate        = %s\n", ptrinfo->bitrate );
+		g_print( "\tptrinfo->mpeg_is        = %d\n", ptrinfo->mpeg_is );
+		g_print( "\tptrinfo->size           = %s\n", ptrinfo->size );
+	}
+}
+
 INFO_MP3 *tagsmp3_get_info (DETAIL *detail)
 {
 	INFO_MP3     *ptrinfo = NULL;
@@ -169,65 +191,67 @@ INFO_MP3 *tagsmp3_get_info (DETAIL *detail)
 	gint		m;
 	gint		s;
 	gint		sec;
-	
+
 	/* PRINT_FUNC_LF();*/
-	
+
 	ptrinfo = (INFO_MP3 *)g_malloc0 (sizeof (INFO_MP3));
 	if (ptrinfo == NULL) return (NULL);
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
-	
+
 	if ((file = taglib_file_new (detail->namefile))) {
-	
+
 		taglib_set_strings_unicode(FALSE);
 		tag = taglib_file_tag(file);
 		properties = taglib_file_audioproperties(file);
-		
+
 		ptrinfo->tags->Title     = g_strdup (taglib_tag_title(tag));
 		// ptrinfo->tags->Title     = utils_convert_string (taglib_tag_title(tag), TRUE);
-		
-		
+
+
 		ptrinfo->tags->Artist    = g_strdup (taglib_tag_artist(tag));
 		// ptrinfo->tags->Artist    = utils_convert_string (taglib_tag_artist(tag), TRUE);
-		
-		
+
+
 		ptrinfo->tags->Album     = g_strdup (taglib_tag_album(tag));
 		// ptrinfo->tags->Album     = utils_convert_string (taglib_tag_album(tag), TRUE);
-		
-		
+
+
 		ptrinfo->tags->IntYear   = taglib_tag_year(tag);
 		ptrinfo->tags->Year      = g_strdup_printf ("%d", ptrinfo->tags->IntYear);
 		ptrinfo->tags->Comment   = g_strdup (taglib_tag_comment(tag));
 		// ptrinfo->tags->Comment   = utils_convert_string (taglib_tag_comment(tag), TRUE);
-		
+
 		ptrinfo->tags->IntNumber = taglib_tag_track(tag);
 		ptrinfo->tags->Number    = g_strdup_printf ("%d", ptrinfo->tags->IntNumber);
 		ptrinfo->tags->Genre     = g_strdup (taglib_tag_genre(tag));
 		// ptrinfo->tags->Genre     = utils_convert_string (taglib_tag_genre(tag), TRUE);
-		
-		
+
+
 		ptrinfo->tags->IntGenre  = tags_get_genre_by_value (ptrinfo->tags->Genre);
-		
+
 		ptrinfo->SecTime =
 		sec = taglib_audioproperties_length(properties);
 		s = sec % 60; sec /= 60;
 		m = sec % 60; sec /= 60;
 		if (sec > 0) ptrinfo->time = g_strdup_printf ("%02d:%02d:%02d", sec, m, s);
 		else         ptrinfo->time = g_strdup_printf ("%02d:%02d", m, s);
-		
+
 		ptrinfo->bitrate  = g_strdup_printf ("%d", taglib_audioproperties_bitrate(properties));
 		ptrinfo->mpeg_is  = tagsmp3_type_mpeg (detail->namefile);
 		ptrinfo->size     = g_strdup_printf ("%d Ko", (gint)libutils_get_size_file (detail->namefile) / 1024);
-			
+
 		taglib_tag_free_strings();
 		taglib_file_free (file);
 	}
 	/*
 	ptrinfo->level = level_get_from (FILE_IS_MP3, namefile);
-g_print ("%s\t%d\n", namefile, ptrinfo->level);
+	g_print ("%s\t%d\n", namefile, ptrinfo->level);
 	*/
 	ptrinfo->LevelDbfs.level = -1;
 	ptrinfo->LevelDbfs.NewLevel = -1;
 
+	tagsmp3_print( detail->namefile, ptrinfo );
+
 	return (ptrinfo);
 }
 
